@@ -1,4 +1,4 @@
-/* Copyright © 2009 Jakub Wilk
+/* Copyright © 2009, 2011 Jakub Wilk
  *
  * This package is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -8,7 +8,6 @@
 #include "pdf-dpi.hh"
 
 #include <limits>
-#include <iostream>
 
 class DpiGuessDevice : public pdf::OutputDevice
 {
@@ -120,7 +119,7 @@ pdf::dpi::Guess pdf::dpi::Guesser::operator[](int n)
 {
   DpiGuessDevice *guess_device = static_cast<DpiGuessDevice*>(this->magic);
   guess_device->reset();
-  this->document.displayPages(guess_device, n, n, 72, 72, 0, true, false, false, false);
+  this->document.displayPages(guess_device, n, n, 72, 72, 0, true, false, false);
   double min = guess_device->min();
   double max = guess_device->max();
   if (max == 0.0)
